@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;
 use vars '$VERSION';
-$VERSION = '3.19';
+$VERSION = '3.20';
 
 
 use Log::Report          'xml-compile-soap';
@@ -396,7 +396,7 @@ sub _writer_xop_hook($)
         $node;
       };
 
-   +{ type => 'xsd:base64Binary', replace => $collect_objects };
+   +{ extends => 'xsd:base64Binary', replace => $collect_objects };
 }
 
 #------------------------------------------------
